@@ -1,6 +1,6 @@
 'use strict';
 const chalk = require('chalk');
-const boxen = require('./');
+const boxen = require('.');
 
 console.log('\n\n' + boxen(chalk.blue.bold('unicorn'), {
 	padding: 1,
@@ -15,6 +15,21 @@ console.log('\n\n' + boxen(chalk.blue.bold('unicorn'), {
 	borderStyle: 'double'
 }) + '\n');
 
+console.log('\n\n' + boxen(chalk.blue.bold('unicorn'), {
+	padding: 1,
+	margin: 1,
+	borderColor: '#eebbaa',
+	borderStyle: 'double'
+}) + '\n');
+
+console.log('\n\n' + boxen(chalk.blue.bold('unicorn'), {
+	padding: 1,
+	margin: 1,
+	borderColor: '#ffc0cb',
+	backgroundColor: '#00ffff',
+	borderStyle: 'double'
+}) + '\n');
+
 console.log('\n\n' + boxen(chalk.blue.bold('unicorn'), {
 	padding: 1,
 	margin: 1,
